==> zziplib-0.13.60-x86_64-2ponce.txz: install/doinst.sh <==
( cd usr/lib64 ; rm -rf libzzipfseeko-0.so.10 )
( cd usr/lib64 ; ln -sf libzzipfseeko-0.so.13 libzzipfseeko-0.so.10 )
( cd usr/lib64 ; rm -rf libzzip-0.so.13 )
( cd usr/lib64 ; ln -sf libzzip-0.so.13.0.60 libzzip-0.so.13 )
( cd usr/lib64 ; rm -rf libzzipfseeko-0.so.12 )
( cd usr/lib64 ; ln -sf libzzipfseeko-0.so.13 libzzipfseeko-0.so.12 )
( cd usr/lib64 ; rm -rf libzzip-0.so.10 )
( cd usr/lib64 ; ln -sf libzzip-0.so.13 libzzip-0.so.10 )
( cd usr/lib64 ; rm -rf libzzip-0.so.11 )
( cd usr/lib64 ; ln -sf libzzip-0.so.13 libzzip-0.so.11 )
( cd usr/lib64 ; rm -rf libzzip-0.so.12 )
( cd usr/lib64 ; ln -sf libzzip-0.so.13 libzzip-0.so.12 )
( cd usr/lib64 ; rm -rf libzzipwrap.so )
( cd usr/lib64 ; ln -sf libzzipwrap-0.so.13.0.60 libzzipwrap.so )
( cd usr/lib64 ; rm -rf libzzipmmapped-0.so.10 )
( cd usr/lib64 ; ln -sf libzzipmmapped-0.so.13 libzzipmmapped-0.so.10 )
( cd usr/lib64 ; rm -rf libzzipfseeko-0.so.11 )
( cd usr/lib64 ; ln -sf libzzipfseeko-0.so.13 libzzipfseeko-0.so.11 )
( cd usr/lib64 ; rm -rf libzzipfseeko-0.so.13 )
( cd usr/lib64 ; ln -sf libzzipfseeko-0.so.13.0.60 libzzipfseeko-0.so.13 )
( cd usr/lib64 ; rm -rf libzzipmmapped-0.so.11 )
( cd usr/lib64 ; ln -sf libzzipmmapped-0.so.13 libzzipmmapped-0.so.11 )
( cd usr/lib64 ; rm -rf libzzipmmapped.so )
( cd usr/lib64 ; ln -sf libzzipmmapped-0.so.13.0.60 libzzipmmapped.so )
( cd usr/lib64 ; rm -rf libzzipmmapped-0.so.13 )
( cd usr/lib64 ; ln -sf libzzipmmapped-0.so.13.0.60 libzzipmmapped-0.so.13 )
( cd usr/lib64 ; rm -rf libzzip.so )
( cd usr/lib64 ; ln -sf libzzip-0.so.13.0.60 libzzip.so )
( cd usr/lib64 ; rm -rf libzzipfseeko.so )
( cd usr/lib64 ; ln -sf libzzipfseeko-0.so.13.0.60 libzzipfseeko.so )
( cd usr/lib64 ; rm -rf libzzipwrap-0.so.13 )
( cd usr/lib64 ; ln -sf libzzipwrap-0.so.13.0.60 libzzipwrap-0.so.13 )
( cd usr/lib64 ; rm -rf libzzipmmapped-0.so.12 )
( cd usr/lib64 ; ln -sf libzzipmmapped-0.so.13 libzzipmmapped-0.so.12 )

==> zziplib-0.13.62-x86_64-1ponce.txz: install/doinst.sh <==
( cd usr/lib64 ; rm -rf libzzipfseeko-0.so.11 )
( cd usr/lib64 ; ln -sf libzzipfseeko-0.so.13 libzzipfseeko-0.so.11 )
( cd usr/lib64 ; rm -rf libzzip.so )
( cd usr/lib64 ; ln -sf libzzip-0.so.13.0.62 libzzip.so )
( cd usr/lib64 ; rm -rf libzzipfseeko.so )
( cd usr/lib64 ; ln -sf libzzipfseeko-0.so.13.0.62 libzzipfseeko.so )
( cd usr/lib64 ; rm -rf libzzip-0.so.13 )
( cd usr/lib64 ; ln -sf libzzip-0.so.13.0.62 libzzip-0.so.13 )
( cd usr/lib64 ; rm -rf libzzipfseeko-0.so.10 )
( cd usr/lib64 ; ln -sf libzzipfseeko-0.so.13 libzzipfseeko-0.so.10 )
( cd usr/lib64 ; rm -rf libzzip-0.so.11 )
( cd usr/lib64 ; ln -sf libzzip-0.so.13 libzzip-0.so.11 )
( cd usr/lib64 ; rm -rf libzzipwrap-0.so.13 )
( cd usr/lib64 ; ln -sf libzzipwrap-0.so.13.0.62 libzzipwrap-0.so.13 )
( cd usr/lib64 ; rm -rf libzzipmmapped.so )
( cd usr/lib64 ; ln -sf libzzipmmapped-0.so.13.0.62 libzzipmmapped.so )
( cd usr/lib64 ; rm -rf libzzipmmapped-0.so.10 )
( cd usr/lib64 ; ln -sf libzzipmmapped-0.so.13 libzzipmmapped-0.so.10 )
( cd usr/lib64 ; rm -rf libzzipwrap.so )
( cd usr/lib64 ; ln -sf libzzipwrap-0.so.13.0.62 libzzipwrap.so )
( cd usr/lib64 ; rm -rf libzzipmmapped-0.so.13 )
( cd usr/lib64 ; ln -sf libzzipmmapped-0.so.13.0.62 libzzipmmapped-0.so.13 )
( cd usr/lib64 ; rm -rf libzzipfseeko-0.so.13 )
( cd usr/lib64 ; ln -sf libzzipfseeko-0.so.13.0.62 libzzipfseeko-0.so.13 )
( cd usr/lib64 ; rm -rf libzzip-0.so.12 )
( cd usr/lib64 ; ln -sf libzzip-0.so.13 libzzip-0.so.12 )
( cd usr/lib64 ; rm -rf libzzipmmapped-0.so.12 )
( cd usr/lib64 ; ln -sf libzzipmmapped-0.so.13 libzzipmmapped-0.so.12 )
( cd usr/lib64 ; rm -rf libzzipfseeko-0.so.12 )
( cd usr/lib64 ; ln -sf libzzipfseeko-0.so.13 libzzipfseeko-0.so.12 )
( cd usr/lib64 ; rm -rf libzzip-0.so.10 )
( cd usr/lib64 ; ln -sf libzzip-0.so.13 libzzip-0.so.10 )
( cd usr/lib64 ; rm -rf libzzipmmapped-0.so.11 )
( cd usr/lib64 ; ln -sf libzzipmmapped-0.so.13 libzzipmmapped-0.so.11 )
